Changelog
=========

Unreleased_
-----------

0.0.2_
------

Changed
^^^^^^^

-   Version number to appease PyPI

0.0.1_
------

-   Initial release

.. _Unreleased: https://github.com/kprussing/kpruss/compare/v0.0.2...HEAD
.. _0.0.2: https://github.com/kprussing/kpruss/releases/tag/v0.0.2
.. _0.0.1: https://github.com/kprussing/kpruss/releases/tag/v0.0.1
